pub struct BrowserPolicy { /* private fields */ }Implementations
Sourceimpl BrowserPolicy
impl BrowserPolicy
Sourcepub fn from_preset(
preset: PolicyPreset,
workspace_root: impl AsRef<Path>,
) -> Result<Self, PolicyError>
pub fn from_preset( preset: PolicyPreset, workspace_root: impl AsRef<Path>, ) -> Result<Self, PolicyError>
Create a policy from a preset and workspace root.
pub fn development( workspace_root: impl AsRef<Path>, ) -> Result<Self, PolicyError>
pub fn ci(workspace_root: impl AsRef<Path>) -> Result<Self, PolicyError>
pub fn polite(workspace_root: impl AsRef<Path>) -> Result<Self, PolicyError>
pub fn hardened(workspace_root: impl AsRef<Path>) -> Result<Self, PolicyError>
pub fn untrusted_mcp( workspace_root: impl AsRef<Path>, ) -> Result<Self, PolicyError>
pub fn new( preset: PolicyPreset, workspace_root: impl AsRef<Path>, allowed_capabilities: impl IntoIterator<Item = PolicyCapability>, confirmed_capabilities: impl IntoIterator<Item = PolicyCapability>, ) -> Result<Self, PolicyError>
pub fn with_host_rules( self, allowed_hosts: impl IntoIterator<Item = String>, denied_hosts: impl IntoIterator<Item = String>, ) -> Result<Self, PolicyError>
pub fn preset(&self) -> PolicyPreset
pub fn with_confirmation_tokens( self, capabilities: impl IntoIterator<Item = PolicyCapability>, ) -> Result<Self, PolicyError>
pub fn workspace_root(&self) -> &Path
pub async fn prepare_hardened_session( &mut self, attached: bool, ) -> Result<Option<String>, PolicyError>
pub fn decide(&self, capability: PolicyCapability) -> PolicyDecision
pub fn require(&self, capability: PolicyCapability) -> Result<(), PolicyError>
Sourcepub fn require_for_batch(
&self,
capability: PolicyCapability,
) -> Result<(), PolicyError>
pub fn require_for_batch( &self, capability: PolicyCapability, ) -> Result<(), PolicyError>
Check a capability without consuming a confirmation token. Batch preflight uses this so a token cannot be spent before the batch starts or be smuggled into a multi-step request.
Sourcepub fn allow_sensitive_form_values(&self) -> bool
pub fn allow_sensitive_form_values(&self) -> bool
Whether sensitive form values (passwords, CC numbers) may be read.
This capability is denied in ALL presets by default and must be
explicitly added to allowed_capabilities.
pub async fn require_url(&self, value: &str) -> Result<Url, PolicyError>
pub fn require_existing_path( &self, value: &Path, ) -> Result<PathBuf, PolicyError>
pub fn require_output_path(&self, value: &Path) -> Result<PathBuf, PolicyError>
pub fn is_polite(&self) -> bool