pub enum WorkflowTransactionClass {
ReadOnly,
Idempotent,
ConditionallyIdempotent,
NonIdempotent,
Unknown,
}Expand description
Effect classification used to decide whether a failed attempt may be replayed before dispatch.
Variants
Implementations
Sourceimpl WorkflowTransactionClass
impl WorkflowTransactionClass
Sourcepub fn permits_pre_dispatch_retry(self) -> bool
pub fn permits_pre_dispatch_retry(self) -> bool
Whether this class permits a retry known to have happened before dispatch.