pub fn normalize_intent(
request: &SemanticIntentRequest,
) -> Result<NormalizedSemanticIntent, IntentResolutionError>Expand description
Normalize one request without consulting a browser or external service.
pub fn normalize_intent(
request: &SemanticIntentRequest,
) -> Result<NormalizedSemanticIntent, IntentResolutionError>Normalize one request without consulting a browser or external service.