pub struct ActionOutcome {
pub status: ActionStatus,
pub action: ActionKind,
pub execution_id: String,
pub target: Option<ActionTarget>,
pub revision: u64,
pub previous_revision: u64,
pub current_revision: u64,
pub target_id: String,
pub frame_id: String,
pub verification: ActionVerificationEvidence,
pub evidence: Option<Value>,
}Expand description
A compact, serializable result from an input action.
revision is the generation after the action invalidated page context. A
caller should observe again before reusing a previous element reference.
Fields
status: ActionStatusaction: ActionKindexecution_id: Stringtarget: Option<ActionTarget>revision: u64previous_revision: u64current_revision: u64target_id: Stringframe_id: Stringverification: ActionVerificationEvidenceevidence: Option<Value>Trait Implementations
Sourceimpl Clone for ActionOutcome
impl Clone for ActionOutcome
Sourcefn clone(&self) -> ActionOutcome
fn clone(&self) -> ActionOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionOutcome
impl Debug for ActionOutcome