pub struct WorkflowRecordedRoute {
pub target_digest: String,
pub frame_digest: String,
pub url: String,
}Expand description
Bounded route evidence captured by a semantic recorder.
Browser target and frame handles are hashed because they are useful for comparing a recording with later evidence but are not valid replay selectors. Query strings and fragments are removed from the retained URL.
Fields
target_digest: Stringframe_digest: Stringurl: StringTrait Implementations
Sourceimpl Clone for WorkflowRecordedRoute
impl Clone for WorkflowRecordedRoute
Sourcefn clone(&self) -> WorkflowRecordedRoute
fn clone(&self) -> WorkflowRecordedRoute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowRecordedRoute
impl Debug for WorkflowRecordedRoute
Sourceimpl<'de> Deserialize<'de> for WorkflowRecordedRoute
impl<'de> Deserialize<'de> for WorkflowRecordedRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more