pub enum CertifyCommand {
Run {
scenario: PathBuf,
fixture: PathBuf,
url: String,
workflow_root: PathBuf,
inputs: Option<PathBuf>,
output: Option<PathBuf>,
},
Plan {
scenario: PathBuf,
fixture: PathBuf,
},
Release {
version: String,
scenarios: PathBuf,
observations: PathBuf,
replays: Option<PathBuf>,
},
Replay {
scenario: PathBuf,
input: PathBuf,
},
ReplayDiff {
scenario: PathBuf,
before: PathBuf,
after: PathBuf,
},
}Variants
Run
Run one scenario in a navigated browser fixture and emit evidence.
Fields
Plan
Expand a scenario into its manifest-bound execution plan.
Fields
Release
Evaluate a release-blocking reliability gate.
Fields
Replay
Validate one redacted replay bundle against its versioned scenario.
Fields
ReplayDiff
Compare two redacted replay bundles for one scenario.