pub enum IrCommand {
Validate {
input: PathBuf,
},
Inspect {
input: PathBuf,
},
Diff {
before: PathBuf,
after: PathBuf,
summary: bool,
},
Continuity {
before: PathBuf,
after: PathBuf,
entity_id: String,
},
Canonical {
input: PathBuf,
},
}Variants
Validate
Validate one Web IR draft without starting Chrome.
Inspect
Print a bounded summary of one validated Web IR draft.
Diff
Compute a deterministic diff between two validated Web IR drafts.
Fields
Continuity
Classify one entity’s continuity across two validated Web IR drafts.
Canonical
Print one validated Web IR draft in canonical JSON form.