pub struct MutationLeaseManager { /* private fields */ }Expand description
In-memory lease authority for one daemon session namespace.
Implementations
Sourceimpl MutationLeaseManager
impl MutationLeaseManager
Sourcepub fn acquire(
&mut self,
session_id: &str,
owner_id: &str,
now_ms: u64,
ttl_ms: u64,
) -> Result<MutationLease, LeaseError>
pub fn acquire( &mut self, session_id: &str, owner_id: &str, now_ms: u64, ttl_ms: u64, ) -> Result<MutationLease, LeaseError>
Acquire the only mutation lease for a session.
Sourcepub fn renew(
&mut self,
session_id: &str,
owner_id: &str,
token: &str,
now_ms: u64,
ttl_ms: u64,
) -> Result<MutationLease, LeaseError>
pub fn renew( &mut self, session_id: &str, owner_id: &str, token: &str, now_ms: u64, ttl_ms: u64, ) -> Result<MutationLease, LeaseError>
Renew a lease without allowing a different owner to take it over.
Sourcepub fn release(
&mut self,
session_id: &str,
owner_id: &str,
token: &str,
) -> Result<(), LeaseError>
pub fn release( &mut self, session_id: &str, owner_id: &str, token: &str, ) -> Result<(), LeaseError>
Release a lease only when the owner and token match.
Sourcepub fn validate(
&self,
session_id: &str,
owner_id: &str,
token: &str,
now_ms: u64,
) -> Result<(), LeaseError>
pub fn validate( &self, session_id: &str, owner_id: &str, token: &str, now_ms: u64, ) -> Result<(), LeaseError>
Verify that a mutation request is still owned by the given client.
Sourcepub fn release_owner(&mut self, owner_id: &str)
pub fn release_owner(&mut self, owner_id: &str)
Release every lease held by a disconnected client owner.