pub struct ExtensionGuardedAction {
pub action: String,
pub target: Option<String>,
pub value: Option<String>,
pub expected_revision: u64,
}Expand description
A bounded action request returned by an extension for core dispatch.
Extensions do not receive browser handles and cannot call CDP. The only
way for an extension result to cause a browser mutation is to return this
shape to ExtensionHost::invoke_guarded, which requires a current
observation revision and routes the operation through BrowserSession.
Fields
action: Stringtarget: Option<String>value: Option<String>expected_revision: u64Trait Implementations
Sourceimpl Clone for ExtensionGuardedAction
impl Clone for ExtensionGuardedAction
Sourcefn clone(&self) -> ExtensionGuardedAction
fn clone(&self) -> ExtensionGuardedAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionGuardedAction
impl Debug for ExtensionGuardedAction
Sourceimpl<'de> Deserialize<'de> for ExtensionGuardedAction
impl<'de> Deserialize<'de> for ExtensionGuardedAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more