pub struct EvidenceFact {
pub source: EvidenceSource,
pub kind: String,
pub quality: EvidenceQuality,
pub role: Option<String>,
pub name: Option<String>,
pub parent_role: Option<String>,
pub relationship_hint: Option<EvidenceRelationshipHint>,
pub input_type: Option<String>,
pub required: Option<bool>,
pub read_only: Option<bool>,
pub empty: Option<bool>,
pub geometry_present: Option<bool>,
}Expand description
One redacted, source-labelled fact from browser evidence.
Fields
source: EvidenceSourcekind: Stringquality: EvidenceQualityrole: Option<String>name: Option<String>parent_role: Option<String>Bounded observed accessibility region role for relationship reconciliation.
relationship_hint: Option<EvidenceRelationshipHint>Explicit semantic relationship, when a source can prove one.
input_type: Option<String>required: Option<bool>read_only: Option<bool>empty: Option<bool>geometry_present: Option<bool>Implementations
Sourceimpl EvidenceFact
impl EvidenceFact
Sourcepub fn validate_relationship_hint(
&self,
path: &str,
) -> Result<(), ExtractionContractError>
pub fn validate_relationship_hint( &self, path: &str, ) -> Result<(), ExtractionContractError>
Validate one explicit relationship hint and its required parent role.