pub enum ReliabilityFaultKind {
LoseResponse,
RendererDisconnect,
BrowserDisconnect,
DelayedEffect,
DropEvent,
}Expand description
Faults that the reliability lab can inject without relying on timing races.
Variants
Implementations
Sourceimpl ReliabilityFaultKind
impl ReliabilityFaultKind
Sourcepub const fn fixture_name(self) -> &'static str
pub const fn fixture_name(self) -> &'static str
Return the stable fixture argument used by a runner.