pub struct ReliabilityFixtureManifest {
pub schema_version: u32,
pub id: String,
pub entrypoint: String,
pub controls: Vec<ReliabilityFixtureControl>,
pub faults: Vec<ReliabilityFaultKind>,
pub oracles: Vec<ReliabilityFixtureOracle>,
}Expand description
Versioned manifest for a deterministic browser fixture.
Fields
schema_version: u32id: Stringentrypoint: Stringcontrols: Vec<ReliabilityFixtureControl>faults: Vec<ReliabilityFaultKind>oracles: Vec<ReliabilityFixtureOracle>Implementations
Sourceimpl ReliabilityFixtureManifest
impl ReliabilityFixtureManifest
Sourcepub fn from_json(input: &str) -> Result<Self, ReliabilityScenarioError>
pub fn from_json(input: &str) -> Result<Self, ReliabilityScenarioError>
Parse and validate one fixture manifest.
Sourcepub fn validate(&self) -> Result<(), ReliabilityScenarioError>
pub fn validate(&self) -> Result<(), ReliabilityScenarioError>
Validate the fixture identity, controls, faults, and independent oracles.
Sourcepub fn content_hash(&self) -> Result<String, ReliabilityScenarioError>
pub fn content_hash(&self) -> Result<String, ReliabilityScenarioError>
Return the stable content hash used to bind fixture evidence.
Sourcepub fn validate_scenario(
&self,
scenario: &ReliabilityScenario,
) -> Result<(), ReliabilityScenarioError>
pub fn validate_scenario( &self, scenario: &ReliabilityScenario, ) -> Result<(), ReliabilityScenarioError>
Check that a scenario only uses controls and faults exposed by this fixture.