pub struct DraftEntity {
pub id: String,
pub kind: DraftEntityKind,
pub role: Option<String>,
pub name: Option<String>,
pub quality: EvidenceQuality,
pub evidence_sources: Vec<EvidenceSource>,
}Expand description
One canonical entity reconciled from one or more evidence sources.
Fields
id: Stringkind: DraftEntityKindrole: Option<String>name: Option<String>quality: EvidenceQualityevidence_sources: Vec<EvidenceSource>Implementations
Sourceimpl DraftEntity
impl DraftEntity
Sourcepub fn semantic_identity_key(&self) -> Option<String>
pub fn semantic_identity_key(&self) -> Option<String>
Return a bounded semantic key suitable only for revision comparison.